Shape

Enum Shape 

pub enum Shape {
    Group(Group),
    Style {
        fill: Option<Fill>,
        stroke: Option<Stroke>,
        shape: Box<Shape>,
    },
    Ellipse(Ellipse),
    Image(Image),
    Text(Text),
    Curve(Curve),
    Dynamic {
        local_transform: Transform2<f32>,
        shaper: Arc<Shaper>,
    },
}
Building block of a dessin

Every complex shape should boil down to these.

Variants



Group(Group)

A group of Shape, locally positionned by a transform



Style

Block of style

Fields

fill: Option<Fill>

Fill

stroke: Option<Stroke>

Stroke

shape: Box<Shape>

Styled shape. (Or Shapes if it is a Groupe)



Ellipse(Ellipse)

Ellipse



Image(Image)

Image



Text(Text)

Text



Curve(Curve)

Curve



Dynamic

Shape whose body is generated only during export.

Enables chirurgical changes of the shape.

See Dynamic for more details.

Fields

local_transform: Transform2<f32>

Transform of the whole group

shaper: Arc<Shaper>

The shape at run time

Implementations

Source

impl Shape

pub fn get_or_mutate_as_group(&mut self) -> &mut Group

Get current shape as group If current shape isn’t a group, morph it into a group

pub fn extend_metadata<K: ToString, V: ToString, E: IntoIterator<Item = (K, V)>>( &mut self, extend: E, )

Add some metadata

pub fn add_metadata<K: ToString, V: ToString>(&mut self, (key, value): (K, V))

Add some metadata