pub enum Shape {
Group(Group),
Style {
fill: Option<Fill>,
stroke: Option<Stroke>,
shape: Box<Shape>,
},
Ellipse(Ellipse),
Image(Image),
Text(Text),
Curve(Curve),
Dynamic {
local_transform: Transform2<f32>,
shaper: Arc<Shaper>,
},
}Expand description
Building block of a dessin
Every complex shape should boil down to these.
Variants
Group(Group)
A group of Shape, locally positionned by a transform
Style
Block of style
Fields
Ellipse(Ellipse)
Ellipse
Image(Image)
Image
Text(Text)
Text
Curve(Curve)
Curve
Dynamic
Shape whose body is generated only during export.
Enables chirurgical changes of the shape.
See Dynamic for more details.
Implementations
Sourceimpl Shape
impl Shape
Sourcepub fn get_or_mutate_as_group(&mut self) -> &mut Group
pub fn get_or_mutate_as_group(&mut self) -> &mut Group
Get current shape as group If current shape isn’t a group, morph it into a group
Sourcepub fn extend_metadata<K: ToString, V: ToString, E: IntoIterator<Item = (K, V)>>(
&mut self,
extend: E,
)
pub fn extend_metadata<K: ToString, V: ToString, E: IntoIterator<Item = (K, V)>>( &mut self, extend: E, )
Add some metadata
Sourcepub fn add_metadata<K: ToString, V: ToString>(&mut self, (key, value): (K, V))
pub fn add_metadata<K: ToString, V: ToString>(&mut self, (key, value): (K, V))
Add some metadata